/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Do file to execute analysis of demographics and automation
Revised by: Pascual Restrepo 1/29/2021
            Eric Donald ...
			
Note: 	This executer requires the .dta files 
		-country_robot_flows			
		-country_robot_stocks
		which are proprietary data belonging to the International Federation of Robotics
	  
		For details on how to obtain the IFR data and for the 
		cleaning procedure used to generate the clean datasets 
		in this replication kit, please email pascual@bu.edu			
			
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* Directories*/
global project "C:\Users\Pascual Restrepo\Dropbox\Research\aging_robotics\revision_restud\replication_kit_restud"

*baseline measure of aging*
global aging_measure dependency_55_y
*covariates used in exercise with population bins*
global country_covariates_min 		log_pwt_output_capita1993 log_pwt_population1993 pwt_human_capital1993 
*covariates used in the main exercises*
global country_covariates 		    log_pwt_output_capita1993 log_pwt_population1993 pwt_human_capital1993 dependency_55_y1990
*covariates in 1990
global country_covariates_1990 		log_pwt_output_capita1990 log_pwt_population1990 pwt_human_capital1990 dependency_55_y1990
*covariates in 1995
global country_covariates_1995 		log_pwt_output_capita1995 log_pwt_population1995 pwt_human_capital1995 dependency_55_y1995
*placebo covariates (excludes dependency in 1990---otherwise, past change hard to interpret) *
global country_covariates_past 	    log_pwt_output_capita1993 log_pwt_population1993 pwt_human_capital1993 
*industry covariates measured in 1995*
global industry_covariates_1995 	log_pwt_output_capita1995 log_pwt_population1995 pwt_human_capital1995 dependency_55_y1995 
*industry covariates measured in 1993*
global industry_covariates 	        log_pwt_output_capita1993 log_pwt_population1993 pwt_human_capital1993 dependency_55_y1990
*placebo industry covariates (excludes dependency in 1990---otherwise, past change hard to interpret) *
global industry_covariates_past     log_pwt_output_capita1993 log_pwt_population1993 pwt_human_capital1993 
* covariates for wage analysis 
global covariates_wages             log_pwt_output_capita1995 log_pwt_population1995 pwt_human_capital1995 base_dependency

*instruments*
global instruments  			birthrate1950_1955 birthrate1955_1960 birthrate1960_1965 birthrate1965_1970 birthrate1970_1975 birthrate1975_1980 birthrate1980_1985
global instruments_adjusted  	birthrate_adj1950_1955 birthrate_adj1955_1960 birthrate_adj1960_1965 birthrate_adj1965_1970 birthrate_adj1970_1975 birthrate_adj1975_1980 birthrate_adj1980_1985

*baseline normalization for number of robots*
global normalization_robots hours_industry_imp

*weighting
global imports_weights    [w=unido_MvaCod_1990]
global exports_weights    [w=unido_MvaCod_1990]
global patent_weights     [w=unido_MvaCod_1990]
global imports90_weights  [w=unido_MvaCod_1990]
global exports90_weights  [w=unido_MvaCod_1990]
global robot_weight       [w=unido_MvaCod_1990]

*****************************************
*********MAIN TABLES AND FIGURES*********
*****************************************

***Figure 3: trends in aging and robot adoption across developed countries ***
run "${project}/dofiles/figure 3---trends in aging and robot adoption across developed countries.do"

***Figure 4: relationship between aging and the adoption of industrial robots***
run "${project}/dofiles/figure 4---relationship between aging and the adoption of industrial robots.do"

***Figures 5 and 6: relationship between aging and imports/exports of industrial robots***
run "${project}/dofiles/figure 5---relationship between aging and imports of industrial robots.do"
run "${project}/dofiles/figure 6---relationship between aging and exports of industrial robots.do"

***Figure 7: relationship between aging and imports/exports of different commodities***
run "${project}/dofiles/figure 7---relationship between aging and trade of different intermediates.do"

***Figure 8: relationship between aging and patents related to automation technologies***
run "${project}/dofiles/figure 8---relationship between aging and patents related to automation technologies.do"

***Figure 9: relationship between aging and different types of patents***
run "${project}/dofiles/figure 9---relationship between aging and different types of patents.do"

***Figure 10: relationship between aging and location of robotics integrators in the US***
run "${project}/dofiles/figure 10---relationship between aging and location of robot integrators.do"

***Figure 11: specialization patterns by age for the US***
run "${project}/dofiles/figure 11---specialization patterns by age.do"

***Figure 12: effects of advances in robotics on workers of different ages across US commuting zones***
run "${project}/dofiles/figure 12---reduced form effects of robots by age group in us czones.do"

***Table 1: summary statistics***
run "${project}/dofiles/table 1---summary statistics for countries.do"

***Table 2: estimates of the impact of aging on the adoption of industrial robots***
run "${project}/dofiles/table 2---estimates of the impact of aging on the adoption of industrial robots.do" 

***Table 3: stacked-differences estimates of the impact of aging on the adoption of industrial robots***
run "${project}/dofiles/table 3---stacked-differences estimates of the impact of aging on the adoption of industrial robots.do" 

***Table 4: estimates of the impact of aging on imports and exports of industrial robots***
run "${project}/dofiles/table 4a---estimates of the impact of aging on imports and exports of industrial robots.do" 
run "${project}/dofiles/table 4b---estimates of the impact of aging on imports and exports of industrial robots.do" 
     
***Table 5: estimates of the impact of aging on patents related to robotics***
run "${project}/dofiles/table 5---estimates of the impact of aging on patents related to robotics.do" 

***Table 6: estimates of the impact of aging on the location of robot integrators in the US***
run "${project}/dofiles/table 6---estimates of the impact of aging on the location of robot integrators in the US.do"

***Table 7: estimates of the impact of aging on robot installations by country-industry pairs***
run "${project}/dofiles/table 7---estimates of the impact of aging on robot installations by country-industry pairs.do"

***Table 8 : estimates of the impact of aging on labor productivity of country-industry pairs ***
run "${project}/dofiles/table 8---estimates of the impact of aging on labor productivity and the labor share of country industry pairs.do"


*********************************
***APPENDIX TABLES AND FIGURES***
*********************************

* appendix figures *
run "${project}/dofiles/figure A1---industry characteristics.do"
run "${project}/dofiles/figure A2---scatter plots in growth rates.do"
run "${project}/dofiles/figure A3 and A4---robustness comtrade.do"
run "${project}/dofiles/figure A5---robustness patents.do"
run "${project}/dofiles/figure A6---validation comtrade.do"
run "${project}/dofiles/figure A7 and A8---specialization patterns by age for other countries.do"

* appendix tables *
run "${project}/dofiles/table A2---summary statistics for industries.do"
run "${project}/dofiles/table A3---robustness using different definitions of age groups.do"
run "${project}/dofiles/table A4---robustness to outliers.do"
run "${project}/dofiles/table A5---correlation of aging and other trends.do"
run "${project}/dofiles/table A6---role of institutional differences.do"
run "${project}/dofiles/table A7---first stage results.do"
run "${project}/dofiles/table A8---age adjusted instruments.do"
run "${project}/dofiles/table A9---estimate effects of different age groups separately.do"
run "${project}/dofiles/table A10---horse race versus population change.do"
run "${project}/dofiles/table A11---estimates of the impact of past and current aging on the adoption of industrial robots.do"
run "${project}/dofiles/table A12---current vs expected aging.do"
run "${project}/dofiles/table A13---robustness current aging up to 2015.do"
run "${project}/dofiles/table A14---cross sectional differences in density of robots.do"
run "${project}/dofiles/table A15---robustness to specifications in growth rates.do"
run "${project}/dofiles/table A16---robustness for exports and imports of robots.do"
run "${project}/dofiles/table A17---robustness patents related to robotics.do"
run "${project}/dofiles/table A18---robustness location of robot integrators in the US.do"
run "${project}/dofiles/table A19---relative wages cross country.do"
run "${project}/dofiles/table A20---relative wages across commuting zones.do"
run "${project}/dofiles/table A21---models for total flows.do"
run "${project}/dofiles/table A22---industry heterogeneity within manufacturing using UNIDO.do"
run "${project}/dofiles/table A23---placebo test for industry heterogeneity.do"
run "${project}/dofiles/table A24 and A25---robustness industry heterogeneity.do"
run "${project}/dofiles/table A26 and A27---specialization patterns and role of education and gender.do"
