/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 10: 	Relationship between aging and location
			of robot integrators
			
Notes: 		1. Uses data from the replication kit of Robots and Jobs
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_integrators_aging.pdf

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* data from R&J *
use "${project}/clean_data/czones_integrators.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_covariates_1990.dta", assert(3) nogenerate

* additional controls and measures of aging *
merge 1:1 czone using "${project}/clean_data/czones_demographics", assert(3) nogenerate

* define alternative instrument *
gen    single_iv=ln(brate1950)-ln(brate1980)
global instruments_czone brate*

* control variables *
gen nhgis_ln_gdp_1990=ln(nhgis_percapita_income_1990)
gen log_pop_1990=ln(population_1990)

*measures of aging: change in dependency ratio between 1990 and 2015 *
gen change_dep=${aging_measure}2015-${aging_measure}1990  
gen base_dep=${aging_measure}1990

*groups of covariates*
global demographics_cz        nhgis_male_share_1990 nhgis_urban_share_1990 base_dep nhgis_ln_gdp_1990 log_pop_1990 nhgis_edu_*1990 nhgis_race_*1990 
global other_shocks_cz        chinashock_iv_90_07 expo_share_occ_routine_1990 
global industry_shares_cz 	   nhgis_empsh_* 
global regional_dummies_cz    i.region

* dummy for location of integrators *
gen loc_integrator=dum_int

	************************
	*******Estimation*******
	************************   

*Gen predicted values*
quietly: reg change_dep $instruments_czone expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
predict change_predicted_full, xb

quietly: reg change_dep single_iv expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
predict change_predicted_single, xb

**********************************************
*********Left Panel of Figure 10**************
**********************************************
* Use predicted aging based on past birthrates *												  
reg loc_integrator change_predicted_full expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz
binscatter loc_integrator change_predicted_full, controls(expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz ) ///
												 color(dkorange) lcolor(navy) ///
												 xtitle(Predicted aging from 1990 to 2015 based on past birthrates, size(large)) ///
												 ytitle("") title("Dummy for location of integrators (binned)",  position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
												 name(full_instruments, replace) nquantiles(25)

**********************************************
********Right Panel of Figure 10**************
**********************************************												 
* Use predicted aging based on decline in birth rates *												  
reg loc_integrator change_predicted_single expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz
binscatter loc_integrator change_predicted_single, controls($expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz ) ///
												 color(dkorange) lcolor(navy) ///
												 xtitle(Predicted aging from 1990 to 2015 based on single IV, size(large)) ///
												 ytitle("") title("Dummy for location of integrators (binned)", position(11)) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ///
												 name(single_instrument, replace) nquantiles(25)
												 
gr combine full_instruments single_instrument, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) xsize(8) cols(2) ycommon 
graph export "$project/results/figure_integrators_aging.pdf", as(pdf) replace
