/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figure 12: 	Reduced form effects of robots by age group
			in US commuting zones
			
Figure A9:  
			
Notes: 		1. Uses data available in the replication kit of
			"Robots and Jobs: Evidence from US labor markets"
			czones_covariates_1990
			czones_exposure_longdif
			2. Produces a version for 10-year groups and for 
			5-year age groups.
			3. This do-file generates tex files for both 
			Figures 12 and A9 as marked below.
			4. This do-file generates unused tex files
			marked below.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_replacement_empman_5yrs.pdf (unused)
			/results/figure_replacement_emppriv_5yrs.pdf (Figure A9)
			/results/figure_replacement_wkwage_ln_5yrs.pdf (Figure A9)
			/results/figure_replacement_empman_10yrs.pdf (unused)
			/results/figure_replacement_emppriv_10yrs.pdf (Figure 12)
			/results/figure_replacement_wkwage_ln_10yrs.pdf (Figure 12)

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

set matsize 4000

/*Based on R&J published version and the covariates used there*/
global demographics_rj    ipums_female_1990 ipums_hispanic_1990 ipums_white_1990 ipums_black_1990 ipums_asian_1990 ipums_highschool_1990 ipums_college_1990 ipums_masters_1990 ipums_above65_1990 ipums_logpop_1990
global industry_shares_rj ind_share_manufacturing_1990 ind_share_manufacturing_f_1990 ind_share_light_manuf_1990
global other_shocks_rj    chinashock_iv_90_07 expo_share_occ_routine_1990 
global region_effects_rj  i.division

* 5-year age groups *
foreach var in  empman emppriv wkwage_ln {

* load data for employment results *
use "${project}/clean_data/czones_outcomes_5years_1990.dta", clear /*1990 Census*/
merge 1:1 czone group using "${project}/clean_data/czones_outcomes_5years_2000.dta", nogenerate /*2006--2008 ACS*/
merge 1:1 czone group using "${project}/clean_data/czones_outcomes_5years_2008.dta", nogenerate /*2006--2008 ACS*/

* group codes *
encode group, gen(group_id)

* generate dependent variable as the change between 1990--2007 (last year using 2006--2008 ACS)
cap drop depvar
gen depvar=100*(ipums_`var'_2008-ipums_`var'_2000 ///
                +0.7*(ipums_`var'_2000-ipums_`var'_1990))
				
* remove observations with no data to speed estimation *
keep if depvar!=.				

* age groups to be used in analysis (5-year groups) *
gen age_group=.
replace age_group=1  if strrpos(group,"a16_20")!=0
replace age_group=2  if strrpos(group,"a21_25")!=0
replace age_group=3  if strrpos(group,"a26_30")!=0
replace age_group=4  if strrpos(group,"a31_35")!=0
replace age_group=5  if strrpos(group,"a36_40")!=0
replace age_group=6  if strrpos(group,"a41_45")!=0
replace age_group=7  if strrpos(group,"a46_50")!=0
replace age_group=8  if strrpos(group,"a51_55")!=0
replace age_group=9  if strrpos(group,"a56_60")!=0
replace age_group=10 if strrpos(group,"a61_65")!=0
replace age_group=11 if strrpos(group,"a66_70")!=0
replace age_group=12 if strrpos(group,"a71_75")!=0
assert age_group!=.

* labels *
label define age_group_lbl 1 "between 16 and 20" ///
						   2 "between 21 and 25" ///
						   3 "between 26 and 30" ///
						   4 "between 31 and 35" ///
						   5 "between 36 and 40" ///
						   6 "between 41 and 45" ///
						   7 "between 46 and 50" ///
						   8 "between 51 and 55" ///
						   9 "between 56 and 60" ///
						  10 "between 61 and 65" ///
						  11 "between 66 and 70" ///
						  12 "between 71 and 75" 						   
label values age_group age_group_lbl 


* weighting: fix composition given by national weights *
bys group_id: egen newwts=total(group_weight_1990)

* collapse by age group and czone: this delivers identical results (but much faster) *
collapse (rawsum) newwts (mean) depvar [w=newwts], by(czone age_group)

* merge data from "Robots and Jobs" replication kit *
merge m:1 czone using "${project}/clean_data/czones_covariates_1990", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif", assert(3) nogenerate
gen detroit=(czone==11600)

* keep relevant variables *
keep newwts depvar expof_euro5_qo93_07 state age_group ${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} division tag_exposure detroit czone ipums_pop_1990

***Average effects***
reg  depvar 	expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj}) ///
				[w=newwts], r cluster(state) 
				
reg  depvar 	expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=newwts], r cluster(state) 
				
***Effects by age group***
quietly: reg    depvar 	ibn.age_group#c.expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj}) ///
				[w=newwts], r cluster(state) 

* store coefficients *
local model1_b_age15_20=_b[1.age_group#c.expof_euro5_qo93_07]		
local model1_b_age20_25=_b[2.age_group#c.expof_euro5_qo93_07]		
local model1_b_age25_30=_b[3.age_group#c.expof_euro5_qo93_07]		
local model1_b_age30_35=_b[4.age_group#c.expof_euro5_qo93_07]		
local model1_b_age35_40=_b[5.age_group#c.expof_euro5_qo93_07]		
local model1_b_age40_45=_b[6.age_group#c.expof_euro5_qo93_07]		
local model1_b_age45_50=_b[7.age_group#c.expof_euro5_qo93_07]		
local model1_b_age50_55=_b[8.age_group#c.expof_euro5_qo93_07]		
local model1_b_age55_60=_b[9.age_group#c.expof_euro5_qo93_07]		
local model1_b_age60_65=_b[10.age_group#c.expof_euro5_qo93_07]		
local model1_b_age65_70=_b[11.age_group#c.expof_euro5_qo93_07]		
local model1_b_age70_75=_b[12.age_group#c.expof_euro5_qo93_07]		
	
local model1_s_age15_20=_se[1.age_group#c.expof_euro5_qo93_07]		
local model1_s_age20_25=_se[2.age_group#c.expof_euro5_qo93_07]		
local model1_s_age25_30=_se[3.age_group#c.expof_euro5_qo93_07]		
local model1_s_age30_35=_se[4.age_group#c.expof_euro5_qo93_07]		
local model1_s_age35_40=_se[5.age_group#c.expof_euro5_qo93_07]		
local model1_s_age40_45=_se[6.age_group#c.expof_euro5_qo93_07]		
local model1_s_age45_50=_se[7.age_group#c.expof_euro5_qo93_07]		
local model1_s_age50_55=_se[8.age_group#c.expof_euro5_qo93_07]		
local model1_s_age55_60=_se[9.age_group#c.expof_euro5_qo93_07]		
local model1_s_age60_65=_se[10.age_group#c.expof_euro5_qo93_07]		
local model1_s_age65_70=_se[11.age_group#c.expof_euro5_qo93_07]		
local model1_s_age70_75=_se[12.age_group#c.expof_euro5_qo93_07]		
	
					
***Effects by age group controlling for areas with high exposure***
quietly: reg    depvar 	ibn.age_group#c.expof_euro5_qo93_07  ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=newwts], r cluster(state) 

* store coefficients *				
local model2_b_age15_20=_b[1.age_group#c.expof_euro5_qo93_07]		
local model2_b_age20_25=_b[2.age_group#c.expof_euro5_qo93_07]		
local model2_b_age25_30=_b[3.age_group#c.expof_euro5_qo93_07]		
local model2_b_age30_35=_b[4.age_group#c.expof_euro5_qo93_07]		
local model2_b_age35_40=_b[5.age_group#c.expof_euro5_qo93_07]		
local model2_b_age40_45=_b[6.age_group#c.expof_euro5_qo93_07]		
local model2_b_age45_50=_b[7.age_group#c.expof_euro5_qo93_07]		
local model2_b_age50_55=_b[8.age_group#c.expof_euro5_qo93_07]		
local model2_b_age55_60=_b[9.age_group#c.expof_euro5_qo93_07]		
local model2_b_age60_65=_b[10.age_group#c.expof_euro5_qo93_07]		
local model2_b_age65_70=_b[11.age_group#c.expof_euro5_qo93_07]		
local model2_b_age70_75=_b[12.age_group#c.expof_euro5_qo93_07]		
		
local model2_s_age15_20=_se[1.age_group#c.expof_euro5_qo93_07]		
local model2_s_age20_25=_se[2.age_group#c.expof_euro5_qo93_07]		
local model2_s_age25_30=_se[3.age_group#c.expof_euro5_qo93_07]		
local model2_s_age30_35=_se[4.age_group#c.expof_euro5_qo93_07]		
local model2_s_age35_40=_se[5.age_group#c.expof_euro5_qo93_07]		
local model2_s_age40_45=_se[6.age_group#c.expof_euro5_qo93_07]		
local model2_s_age45_50=_se[7.age_group#c.expof_euro5_qo93_07]		
local model2_s_age50_55=_se[8.age_group#c.expof_euro5_qo93_07]		
local model2_s_age55_60=_se[9.age_group#c.expof_euro5_qo93_07]		
local model2_s_age60_65=_se[10.age_group#c.expof_euro5_qo93_07]		
local model2_s_age65_70=_se[11.age_group#c.expof_euro5_qo93_07]		
local model2_s_age70_75=_se[12.age_group#c.expof_euro5_qo93_07]		


***Pooled model***
*alternative weighting---each czone gets weight proportional to its population, but demographic composition held fixed*
bysort czone: egen tot_newwts=total(newwts)
gen wpop=ipums_pop_1990*(newwts/tot_newwts)
quietly: reg    depvar 	ibn.age_group#c.expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=wpop], r cluster(state) 

* store coefficients *	
local model3_b_age15_20=_b[1.age_group#c.expof_euro5_qo93_07]		
local model3_b_age20_25=_b[2.age_group#c.expof_euro5_qo93_07]		
local model3_b_age25_30=_b[3.age_group#c.expof_euro5_qo93_07]		
local model3_b_age30_35=_b[4.age_group#c.expof_euro5_qo93_07]		
local model3_b_age35_40=_b[5.age_group#c.expof_euro5_qo93_07]		
local model3_b_age40_45=_b[6.age_group#c.expof_euro5_qo93_07]		
local model3_b_age45_50=_b[7.age_group#c.expof_euro5_qo93_07]		
local model3_b_age50_55=_b[8.age_group#c.expof_euro5_qo93_07]		
local model3_b_age55_60=_b[9.age_group#c.expof_euro5_qo93_07]		
local model3_b_age60_65=_b[10.age_group#c.expof_euro5_qo93_07]		
local model3_b_age65_70=_b[11.age_group#c.expof_euro5_qo93_07]		
local model3_b_age70_75=_b[12.age_group#c.expof_euro5_qo93_07]		
		
local model3_s_age15_20=_se[1.age_group#c.expof_euro5_qo93_07]		
local model3_s_age20_25=_se[2.age_group#c.expof_euro5_qo93_07]		
local model3_s_age25_30=_se[3.age_group#c.expof_euro5_qo93_07]		
local model3_s_age30_35=_se[4.age_group#c.expof_euro5_qo93_07]		
local model3_s_age35_40=_se[5.age_group#c.expof_euro5_qo93_07]		
local model3_s_age40_45=_se[6.age_group#c.expof_euro5_qo93_07]		
local model3_s_age45_50=_se[7.age_group#c.expof_euro5_qo93_07]		
local model3_s_age50_55=_se[8.age_group#c.expof_euro5_qo93_07]		
local model3_s_age55_60=_se[9.age_group#c.expof_euro5_qo93_07]		
local model3_s_age60_65=_se[10.age_group#c.expof_euro5_qo93_07]		
local model3_s_age65_70=_se[11.age_group#c.expof_euro5_qo93_07]		
local model3_s_age70_75=_se[12.age_group#c.expof_euro5_qo93_07]		


***Plot the estimates***
clear
set obs 12

gen model1_b=.
replace model1_b=`model1_b_age15_20' in 1
replace model1_b=`model1_b_age20_25' in 2
replace model1_b=`model1_b_age25_30' in 3
replace model1_b=`model1_b_age30_35' in 4
replace model1_b=`model1_b_age35_40' in 5
replace model1_b=`model1_b_age40_45' in 6
replace model1_b=`model1_b_age45_50' in 7
replace model1_b=`model1_b_age50_55' in 8
replace model1_b=`model1_b_age55_60' in 9
replace model1_b=`model1_b_age60_65' in 10
replace model1_b=`model1_b_age65_70' in 11
replace model1_b=`model1_b_age70_75' in 12

gen model1_s=.
replace model1_s=`model1_s_age15_20' in 1
replace model1_s=`model1_s_age20_25' in 2
replace model1_s=`model1_s_age25_30' in 3
replace model1_s=`model1_s_age30_35' in 4
replace model1_s=`model1_s_age35_40' in 5
replace model1_s=`model1_s_age40_45' in 6
replace model1_s=`model1_s_age45_50' in 7
replace model1_s=`model1_s_age50_55' in 8
replace model1_s=`model1_s_age55_60' in 9
replace model1_s=`model1_s_age60_65' in 10
replace model1_s=`model1_s_age65_70' in 11
replace model1_s=`model1_s_age70_75' in 12

gen model1_min95=model1_b-1.95*model1_s
gen model1_max95=model1_b+1.95*model1_s

gen model1_pos=_n-0.2

gen model2_b=.
replace model2_b=`model2_b_age15_20' in 1
replace model2_b=`model2_b_age20_25' in 2
replace model2_b=`model2_b_age25_30' in 3
replace model2_b=`model2_b_age30_35' in 4
replace model2_b=`model2_b_age35_40' in 5
replace model2_b=`model2_b_age40_45' in 6
replace model2_b=`model2_b_age45_50' in 7
replace model2_b=`model2_b_age50_55' in 8
replace model2_b=`model2_b_age55_60' in 9
replace model2_b=`model2_b_age60_65' in 10
replace model2_b=`model2_b_age65_70' in 11
replace model2_b=`model2_b_age70_75' in 12

gen model2_s=.
replace model2_s=`model2_s_age15_20' in 1
replace model2_s=`model2_s_age20_25' in 2
replace model2_s=`model2_s_age25_30' in 3
replace model2_s=`model2_s_age30_35' in 4
replace model2_s=`model2_s_age35_40' in 5
replace model2_s=`model2_s_age40_45' in 6
replace model2_s=`model2_s_age45_50' in 7
replace model2_s=`model2_s_age50_55' in 8
replace model2_s=`model2_s_age55_60' in 9
replace model2_s=`model2_s_age60_65' in 10
replace model2_s=`model2_s_age65_70' in 11
replace model2_s=`model2_s_age70_75' in 12


gen model2_min95=model2_b-1.95*model2_s
gen model2_max95=model2_b+1.95*model2_s

gen model2_pos=_n

gen model3_b=.
replace model3_b=`model3_b_age15_20' in 1
replace model3_b=`model3_b_age20_25' in 2
replace model3_b=`model3_b_age25_30' in 3
replace model3_b=`model3_b_age30_35' in 4
replace model3_b=`model3_b_age35_40' in 5
replace model3_b=`model3_b_age40_45' in 6
replace model3_b=`model3_b_age45_50' in 7
replace model3_b=`model3_b_age50_55' in 8
replace model3_b=`model3_b_age55_60' in 9
replace model3_b=`model3_b_age60_65' in 10
replace model3_b=`model3_b_age65_70' in 11
replace model3_b=`model3_b_age70_75' in 12

gen model3_s=.
replace model3_s=`model3_s_age15_20' in 1
replace model3_s=`model3_s_age20_25' in 2
replace model3_s=`model3_s_age25_30' in 3
replace model3_s=`model3_s_age30_35' in 4
replace model3_s=`model3_s_age35_40' in 5
replace model3_s=`model3_s_age40_45' in 6
replace model3_s=`model3_s_age45_50' in 7
replace model3_s=`model3_s_age50_55' in 8
replace model3_s=`model3_s_age55_60' in 9
replace model3_s=`model3_s_age60_65' in 10
replace model3_s=`model3_s_age65_70' in 11
replace model3_s=`model3_s_age70_75' in 12


gen model3_min95=model3_b-1.95*model3_s
gen model3_max95=model3_b+1.95*model3_s

gen model3_pos=_n+0.2


if "`var'"=="empman"{
local title "Manufacturing employment rates"
local yscale -1.5(0.25).5
}	   
if "`var'"=="emppriv"{
local title "Employment rates"
local yscale -2(0.5).5
}	   
if "`var'"=="wkwage_ln"{
local title "Log weekly wage rate"
local yscale -3(1)3
}
if "`var'"=="hrwage_ln"{
local title "Log hourly wage rate"
local yscale -3(1)3
}	
twoway (bar model1_b model1_pos, fcolor(white) fintensity(10)  lcolor(black) barwidth(.15)) ///
       (rcap model1_min95 model1_max95 model1_pos, lcolor(black) ) ///
	   (bar model2_b model2_pos, fcolor(cranberry) fintensity(50)  lcolor(black) barwidth(.15)) ///
       (rcap model2_min95 model2_max95 model2_pos, lcolor(black) ) ///
	   (bar model3_b model3_pos, fcolor(dkorange) fintensity(90)  lcolor(black) barwidth(.15)) ///
       (rcap model3_min95 model3_max95 model3_pos, lcolor(black) ) , ///
	   ylabel(`yscale') xscale(alt) xlabel(0.5 " " 1 "16--20" 2 "21--25" 3 "26--30" 4 "31--35" 5 "36--40" 6 "41--45" 7 "46--50" 8 "51--55" 9 "56--60" 10 "61--65" 11 "66--70" 12 "71--75" 12.5 " ", labsize(small)  ticks tlcolor(none)) yline(0,  lcolor(gray)) xtitle("") ytitle("Point estimate") title("`title'") ///
	   graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white) ilcolor(white) lcolor(black)) ///
	   legend(on order(1 "Baseline estimates" 3 "Controls for highly exposed areas" 5 "Weighted estimates") cols(3) region(lcolor(white))) xsize(6) ysize(3)
	   graph export "$project/results/figure_replacement_`var'_5yrs.pdf", as(pdf)  replace
	   
}


* 10-year age groups *
foreach var in  empman emppriv wkwage_ln{

* load data for employment results *
use "${project}/clean_data/czones_outcomes_10years_1990.dta", clear /*1990 Census*/
merge 1:1 czone group using "${project}/clean_data/czones_outcomes_10years_2000.dta", nogenerate /*2006--2008 ACS*/
merge 1:1 czone group using "${project}/clean_data/czones_outcomes_10years_2008.dta", nogenerate /*2006--2008 ACS*/

* group codes *
encode group, gen(group_id)

* generate dependent variable as the change between 1990--2007 (last year using 2006--2008 ACS)
cap drop depvar
gen depvar=100*(ipums_`var'_2008-ipums_`var'_2000 ///
                +0.7*(ipums_`var'_2000-ipums_`var'_1990))
				
* remove observations with no data to speed estimation *
keep if depvar!=.				

* age groups to be used in analysis (5-year groups) *
gen age_group=.
replace age_group=1 if strrpos(group,"a16_25")!=0
replace age_group=2 if strrpos(group,"a26_35")!=0
replace age_group=3 if strrpos(group,"a36_45")!=0
replace age_group=4 if strrpos(group,"a46_55")!=0
replace age_group=5 if strrpos(group,"a56_65")!=0
replace age_group=6 if strrpos(group,"a66_75")!=0
assert age_group!=.


label define age_group_lbl 1 "between 16 and 25" ///
						   2 "between 26 and 35" ///
						   3 "between 36 and 45" ///
						   4 "between 46 and 55" ///
						   5 "between 56 and 65" ///
						   6 "between 66 and 75" 
label values age_group age_group_lbl 


* weighting: fix composition given by national weights *
bys group_id: egen newwts=total(group_weight_1990)

* collapse by age group and czone: this delivers identical results *
collapse (rawsum) newwts (mean) depvar [w=newwts], by(czone age_group)

* merge data from "Robots and Jobs" replication kit *
merge m:1 czone using "${project}/clean_data/czones_covariates_1990", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif", assert(3) nogenerate
gen detroit=(czone==11600)

* keep relevant variables *
keep newwts depvar expof_euro5_qo93_07 expof_euro5_qo93_07 state age_group ${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} division tag_exposure detroit czone ipums_pop_1990

***Average effects***
reg   depvar 	expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj}) ///
				[w=newwts],  r cluster(state) 
				
reg  depvar 	expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=newwts],  r cluster(state) 
				
***Effects by age group***
quietly: reg    depvar 	ibn.age_group#c.expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj}) ///
				[w=newwts],  r cluster(state) 
				
* store coefficients *
local model1_b_age15_25=_b[1.age_group#c.expof_euro5_qo93_07]		
local model1_b_age25_35=_b[2.age_group#c.expof_euro5_qo93_07]		
local model1_b_age35_45=_b[3.age_group#c.expof_euro5_qo93_07]		
local model1_b_age45_55=_b[4.age_group#c.expof_euro5_qo93_07]		
local model1_b_age55_65=_b[5.age_group#c.expof_euro5_qo93_07]		
local model1_b_age65_75=_b[6.age_group#c.expof_euro5_qo93_07]

local model1_s_age15_25=_se[1.age_group#c.expof_euro5_qo93_07]		
local model1_s_age25_35=_se[2.age_group#c.expof_euro5_qo93_07]		
local model1_s_age35_45=_se[3.age_group#c.expof_euro5_qo93_07]		
local model1_s_age45_55=_se[4.age_group#c.expof_euro5_qo93_07]		
local model1_s_age55_65=_se[5.age_group#c.expof_euro5_qo93_07]		
local model1_s_age65_75=_se[6.age_group#c.expof_euro5_qo93_07]		
	
					
***Effects by age group removing areas with high exposure***
quietly: reg    depvar 	ibn.age_group#c.expof_euro5_qo93_07 ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=newwts], r cluster(state) 
				
* store coefficients *				
local model2_b_age15_25=_b[1.age_group#c.expof_euro5_qo93_07]		
local model2_b_age25_35=_b[2.age_group#c.expof_euro5_qo93_07]		
local model2_b_age35_45=_b[3.age_group#c.expof_euro5_qo93_07]		
local model2_b_age45_55=_b[4.age_group#c.expof_euro5_qo93_07]		
local model2_b_age55_65=_b[5.age_group#c.expof_euro5_qo93_07]		
local model2_b_age65_75=_b[6.age_group#c.expof_euro5_qo93_07]

local model2_s_age15_25=_se[1.age_group#c.expof_euro5_qo93_07]		
local model2_s_age25_35=_se[2.age_group#c.expof_euro5_qo93_07]		
local model2_s_age35_45=_se[3.age_group#c.expof_euro5_qo93_07]		
local model2_s_age45_55=_se[4.age_group#c.expof_euro5_qo93_07]		
local model2_s_age55_65=_se[5.age_group#c.expof_euro5_qo93_07]		
local model2_s_age65_75=_se[6.age_group#c.expof_euro5_qo93_07]		


***Pooled model***
*alternative weighting:
bysort czone: egen tot_newwts=total(newwts)
gen wpop=ipums_pop_1990*(newwts/tot_newwts)
quietly: reg    depvar 	 ibn.age_group#c.expof_euro5_qo93_07   ///
				ibn.age_group#c.(${other_shocks_rj} ${industry_shares_rj} ${demographics_rj} ${region_effects_rj} tag_exposure) ///
				[w=wpop],  r cluster(state)  

* store coefficients *
local model3_b_age15_25=_b[1.age_group#c.expof_euro5_qo93_07]		
local model3_b_age25_35=_b[2.age_group#c.expof_euro5_qo93_07]		
local model3_b_age35_45=_b[3.age_group#c.expof_euro5_qo93_07]		
local model3_b_age45_55=_b[4.age_group#c.expof_euro5_qo93_07]		
local model3_b_age55_65=_b[5.age_group#c.expof_euro5_qo93_07]		
local model3_b_age65_75=_b[6.age_group#c.expof_euro5_qo93_07]

local model3_s_age15_25=_se[1.age_group#c.expof_euro5_qo93_07]		
local model3_s_age25_35=_se[2.age_group#c.expof_euro5_qo93_07]		
local model3_s_age35_45=_se[3.age_group#c.expof_euro5_qo93_07]		
local model3_s_age45_55=_se[4.age_group#c.expof_euro5_qo93_07]		
local model3_s_age55_65=_se[5.age_group#c.expof_euro5_qo93_07]		
local model3_s_age65_75=_se[6.age_group#c.expof_euro5_qo93_07]		


***Plot the estimates***
clear
set obs 6

gen model1_b=.
replace model1_b=`model1_b_age15_25' in 1
replace model1_b=`model1_b_age25_35' in 2
replace model1_b=`model1_b_age35_45' in 3
replace model1_b=`model1_b_age45_55' in 4
replace model1_b=`model1_b_age55_65' in 5
replace model1_b=`model1_b_age65_75' in 6

gen model1_s=.
replace model1_s=`model1_s_age15_25' in 1
replace model1_s=`model1_s_age25_35' in 2
replace model1_s=`model1_s_age35_45' in 3
replace model1_s=`model1_s_age45_55' in 4
replace model1_s=`model1_s_age55_65' in 5
replace model1_s=`model1_s_age65_75' in 6

gen model1_min95=model1_b-1.95*model1_s
gen model1_max95=model1_b+1.95*model1_s

gen model1_pos=_n-0.2

gen model2_b=.
replace model2_b=`model2_b_age15_25' in 1
replace model2_b=`model2_b_age25_35' in 2
replace model2_b=`model2_b_age35_45' in 3
replace model2_b=`model2_b_age45_55' in 4
replace model2_b=`model2_b_age55_65' in 5
replace model2_b=`model2_b_age65_75' in 6

gen model2_s=.
replace model2_s=`model2_s_age15_25' in 1
replace model2_s=`model2_s_age25_35' in 2
replace model2_s=`model2_s_age35_45' in 3
replace model2_s=`model2_s_age45_55' in 4
replace model2_s=`model2_s_age55_65' in 5
replace model2_s=`model2_s_age65_75' in 6

gen model2_min95=model2_b-1.95*model2_s
gen model2_max95=model2_b+1.95*model2_s

gen model2_pos=_n

gen model3_b=.
replace model3_b=`model3_b_age15_25' in 1
replace model3_b=`model3_b_age25_35' in 2
replace model3_b=`model3_b_age35_45' in 3
replace model3_b=`model3_b_age45_55' in 4
replace model3_b=`model3_b_age55_65' in 5
replace model3_b=`model3_b_age65_75' in 6

gen model3_s=.
replace model3_s=`model3_s_age15_25' in 1
replace model3_s=`model3_s_age25_35' in 2
replace model3_s=`model3_s_age35_45' in 3
replace model3_s=`model3_s_age45_55' in 4
replace model3_s=`model3_s_age55_65' in 5
replace model3_s=`model3_s_age65_75' in 6

gen model3_min95=model3_b-1.95*model3_s
gen model3_max95=model3_b+1.95*model3_s

gen model3_pos=_n+0.2

if "`var'"=="empman"{
local title "Manufacturing employment rates"
local yscale -1.5(0.25).5
}	   
if "`var'"=="emppriv"{
local title "Employment rates"
local yscale -2(0.5).5
}	   
if "`var'"=="wkwage_ln"{
local title "Log weekly wage rate"
local yscale -3(1)3
}
if "`var'"=="hrwage_ln"{
local title "Log hourly wage rate"
local yscale -3(1)3
}	

twoway (bar model1_b model1_pos, fcolor(white) fintensity(10)  lcolor(black) barwidth(.15)) ///
       (rcap model1_min95 model1_max95 model1_pos, lcolor(black) ) ///
	   (bar model2_b model2_pos, fcolor(cranberry) fintensity(50)  lcolor(black) barwidth(.15)) ///
       (rcap model2_min95 model2_max95 model2_pos, lcolor(black) ) ///
	   (bar model3_b model3_pos, fcolor(dkorange) fintensity(90)  lcolor(black) barwidth(.15)) ///
       (rcap model3_min95 model3_max95 model3_pos, lcolor(black) ) , ///
	   ylabel(`yscale') xscale(alt) xlabel(0.5 " " 1 "16-25" 2 "26-35" 3 "36-45" 4 "46-55" 5 "56-65" 6 "66-75" 6.5 " ", labsize(small)  ticks tlcolor(none)) yline(0,  lcolor(gray)) xtitle("") ytitle("Point estimate") title("`title'") ///
	   graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) ifcolor(white) ilcolor(white) lcolor(black)) ///
	   legend(on order(1 "Baseline estimates" 3 "Removing highly exposed areas" 5 "Weighted estimates") cols(3) region(lcolor(white))) xsize(6) ysize(3)
	   graph export "$project/results/figure_replacement_`var'_10yrs.pdf", as(pdf)  replace
	   
}
