/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Figures A7
and A8: 	Specialization patterns by age for
			other countries
			
Notes: 		1. The US and Pooled graphs are for Figure A7,
			while the French, German, and Italian graphs
			are for Figure A8.
			2. This do-file generates unused tex files
			marked below.
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 2/3/2021
			
Output: 	/results/figure_specialization_us_appendix.pdf
			/results/figure_specialization_pooled.pdf
			/results/figure_specialization_austria.pdf (unused)
			/results/figure_specialization_china.pdf (unused)
			/results/figure_specialization_france.pdf
			/results/figure_specialization_germany.pdf
			/results/figure_specialization_hungary.pdf (unused)
			/results/figure_specialization_ireland.pdf (unused)
			/results/figure_specialization_italy.pdf
			/results/figure_specialization_portugal.pdf (unused)
			/results/figure_specialization_spain.pdf (unused)
			/results/figure_specialization_switzerland.pdf (unused)
			/results/figure_specialization_uk.pdf (unused)
			/results/figure_specialization_netherlands.pdf (unused)

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

clear all

****************************************
* figures for the US used in appendix  *
*****Bottom Panel of Figure A7**********
****************************************

use "$project/clean_data/specialization_ipums_us1990.dta", clear
merge 1:1 age using "$project/clean_data/specialization_ipums_us2000.dta", assert(3) nogenerate
merge 1:1 age using "$project/clean_data/specialization_ipums_us2008.dta", assert(3) nogenerate
gen upper_limit=.

* smooth data *
rangestat (mean) *_job*, interval(age -2 2)

**********************************************
******Bottom, Left Panel of Figure A7*********
**********************************************
* Share of employment in blue-collar manufacturing jobs *
local var man_blue_job
egen `var'_ave=rowmean(`var'_*_mean)
egen `var'_max=rowmax(`var'_*_mean)
quietly: sum `var'_max
replace upper_limit=`r(max)'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1990_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_2008_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(Share of workers in blue-collar manufacturing jobs, size(large)) xtitle(Age) xlabel(20(5)80) ///
		legend(off)  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)

**********************************************
*****Bottom, Middle Panel of Figure A7********
**********************************************
* Share of employment in blue-collar jobs within manufacturing *
local var cman_blue_job
egen `var'_ave=rowmean(`var'_*_mean)
egen `var'_max=rowmax(`var'_*_mean)
quietly: sum `var'_max
replace upper_limit=`r(max)'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1990_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_2008_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle("Share blue-collar jobs within manufacturing", size(large)) xtitle(Age) xlabel(20(5)80) ///
		legend(off)  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		

**********************************************
*****Bottom, Right Panel of Figure A7*********
**********************************************		
* Share of employment by age in industries with greatest opportunities for industrial robot usage *
local var rel_blue_job 
egen `var'_ave=rowmean(`var'_*_mean)
egen `var'_max=rowmax(`var'_*_mean)
quietly: sum `var'_max
replace upper_limit=`r(max)'
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1990_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_2008_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext', size(large)) xtitle(Age) xlabel(20(5)80) ///
		legend(ring(0) pos(7) order(2 "1990 Census" 3 "2000 Census" 4 "2006-2008 ACS" 5 "Average") cols(1) rows(4) region(lcolor(white)))   graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)


gr combine man_blue_job cman_blue_job rel_blue_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, US") name(combined, replace)
graph export "$project/results/figure_specialization_us_appendix.pdf", as(pdf)  replace
	
*******************************************************
* Pooled figures for other countries different from US*
*************Top Panel of Figure A7********************
*******************************************************
use "${project}/clean_data/specialization_ipums_international_long.dta", clear
drop if country=="US"
encode country, gen(ccode)

* loop over the three measures of specialization *
foreach var in man_ope_job cman_ope_job rel_ope_job{

* titles and legends *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "66--75" 3 "76--85" 4 "86--95" 5 "96--05" 6 "06--15" ) cols(1) rows(5) region(lcolor(white)))
local loptions legend(off)
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(ring(0) pos(2) order(2 "66--75" 3 "76--85" 4 "86--95" 5 "96--05" 6 "06--15" ) cols(1) rows(5) region(lcolor(white)))
}

* tempfiles to store regression results *
tempfile est_result
tempfile cum_est_result

* 66--75 *
reg `var' ibn.age ib14.ccode if year>1965 & year<=1975, noc
parmest,format(estimate) saving(`est_result', replace)
preserve
use `est_result', clear
keep if _n<=60
gen age=20+_n
keep age estimate
rename estimate `var'_1970
save `cum_est_result', replace
restore

* 76--85 *
reg `var' ibn.age ib14.ccode if year>1975 & year<=1985, noc
parmest,format(estimate) saving(`est_result', replace)
preserve
use `est_result', clear
keep if _n<=60
gen age=20+_n
keep age estimate
rename estimate `var'_1980
merge 1:1 age using `cum_est_result', assert(3) nogenerate
save `cum_est_result', replace
restore

* 86--95 *
reg `var' ibn.age ib14.ccode if year>1985 & year<=1995, noc
parmest,format(estimate) saving(`est_result', replace)
preserve
use `est_result', clear
keep if _n<=60
gen age=20+_n
keep age estimate
rename estimate `var'_1990
merge 1:1 age using `cum_est_result', assert(3) nogenerate
save `cum_est_result', replace
restore

* 96--05 *
reg `var' ibn.age ib14.ccode if year>1995 & year<=2005, noc
parmest,format(estimate) saving(`est_result', replace)
preserve
use `est_result', clear
keep if _n<=60
gen age=20+_n
keep age estimate
rename estimate `var'_2000
merge 1:1 age using `cum_est_result', assert(3) nogenerate
save `cum_est_result', replace
restore

* 06--15 *
reg `var' ibn.age ib14.ccode if year>2005 & year<=2015, noc
parmest,format(estimate) saving(`est_result', replace)
preserve
use `est_result', clear
keep if _n<=60
gen age=20+_n
keep age estimate
rename estimate `var'_2010
merge 1:1 age using `cum_est_result', assert(3) nogenerate

* smooth data *
rangestat (mean) `var'*, interval(age -2 2)

* plot * 
egen `var'_max=rowmax(`var'*mean)
quietly: sum `var'_max
gen upper_limit=1.05*`r(max)'

twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'_1970_mean age, mcolor(blue%80)   msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'_1980_mean age, mcolor(red%50)    msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'_1990_mean age, mcolor(gold%50)   msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'_2000_mean age, mcolor(green%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'_2010_mean age, mcolor(orange%50) msymbol(triangle)   mlcolor(black) lcolor(black)), ///
		ylabel(0(.1)`r(max)') ytitle(`ttext', size(large) ) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)

restore

}
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Pooled sample")
graph export "$project/results/figure_specialization_pooled.pdf", as(pdf)  replace

*********************************************
* figures for individual European countries *
**************Figure A8**********************
*********************************************
use "${project}/clean_data/specialization_ipums_international.dta", clear

* smooth data *
rangestat (mean) *_job*, interval(age -2 2)

gen upper_limit=.

* Austria: 2011 data does not include occupational codes* 
drop *Austria2011*
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1971" 3 "1981" 4 "1991" 5 "2001" 6 "Mean") cols(1) rows(5) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Austria_ave=rowmean(`var'Austria*mean)
egen `var'Austria_max=rowmax(`var'Austria*mean)
quietly: sum `var'Austria_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Austria1971_mean age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Austria1981_mean age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Austria1991_mean age, mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Austria2001_mean age, mcolor(purple%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'Austria_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Austria")
graph export "$project/results/figure_specialization_austria.pdf", as(pdf)  replace

* China: version droping rural areas *
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1982" 3 "1990" 4 "2000" 5 "Mean") cols(1) rows(4) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'China_ave=rowmean(`var'China*mean)
egen `var'China_max=rowmax(`var'China*mean)
quietly: sum `var'China_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'China1982_mean age, mcolor(blue%80)  msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'China1990_mean age, mcolor(red%50)   msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'China2000_mean age,  mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'China_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, China")
graph export "$project/results/figure_specialization_china.pdf", as(pdf)  replace

**********************************************
*********Top Panel of Figure A8***************
**********************************************
* France: drop intermediate years for figure *
drop *France2006* 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1975" 3 "1982" 4 "1990" 5 "1999" 6 "2011" 7  "Mean") cols(1) rows(6) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'France_ave=rowmean(`var'France*mean)
egen `var'France_max=rowmax(`var'France*mean)
quietly: sum `var'France_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'France1975_mean age, mcolor(blue%80)   msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'France1982_mean age, mcolor(red%50)    msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'France1990_mean age, mcolor(gold%50)   msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'France1999_mean age, mcolor(purple%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'France2011_mean age, mcolor(orange%50) msymbol(triangle)   mlcolor(black) lcolor(black)) ///
		(connected `var'France_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, France")
graph export "$project/results/figure_specialization_france.pdf", as(pdf)  replace

**********************************************
*******Middle Panel of Figure A8**************
**********************************************	
* Germany: *
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(7) order(2 "1970" 3 "1981" 4 "1987" 5 "Mean") cols(1) rows(4) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Germany_ave=rowmean(`var'Germany*mean)
egen `var'Germany_max=rowmax(`var'Germany*mean)
quietly: sum `var'Germany_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Germany1970_mean age, mcolor(blue%80) msymbol(square) mfcolor(blue%30) mlcolor(black) lcolor(black)) ///
		(connected `var'Germany1981_mean age, mcolor(red%50) msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Germany1987_mean age, mcolor(gold%50) msymbol(circle) mlcolor(black) lcolor(black)) ///
		(connected `var'Germany_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Germany")
graph export "$project/results/figure_specialization_germany.pdf", as(pdf)  replace

* Hungary: no industry data for 70/80/90*
drop *Hungary1970* *Hungary1980* *Hungary1990* 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "2001" 3 "2011" 4  "Mean") cols(1) rows(3) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Hungary_ave=rowmean(`var'Hungary*mean)
egen `var'Hungary_max=rowmax(`var'Hungary*mean)
quietly: sum `var'Hungary_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Hungary2001_mean age, mcolor(blue%80)    msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Hungary2011_mean age, mcolor(red%50)     msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Hungary_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Hungary")
graph export "$project/results/figure_specialization_hungary.pdf", as(pdf)  replace

* Ireland: drop intermediate years*
drop *Ireland2006* *Ireland1986* *Ireland1996*
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1971" 3 "1981" 4 "1991" 5 "2002" 6  "2011" 7 "Mean") cols(1) rows(6) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

gen `var'Ireland_ave=(`var'Ireland1971+`var'Ireland1981+`var'Ireland1991+`var'Ireland2002+`var'Ireland2011_mean)/5
egen `var'Ireland_max=rowmax(`var'Ireland*)
quietly: sum `var'Ireland_max
replace upper_limit=min(.3,`r(max)')
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Ireland1971 age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Ireland1981 age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Ireland1991 age, mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Ireland2002 age, mcolor(purple%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'Ireland2011_mean age, mcolor(orange%50) msymbol(triangle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Ireland_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Ireland")
graph export "$project/results/figure_specialization_ireland.pdf", as(pdf)  replace

**********************************************
*******Bottom Panel of Figure A8**************
**********************************************	
* Italy: ok * 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "2001" 3 "2011" 4 "Mean") cols(1) rows(3) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

gen `var'Italy_ave=(`var'Italy2001+`var'Italy2011_mean)/2
egen `var'Italy_max=rowmax(`var'Italy2001 `var'Italy2011_mean)
quietly: sum `var'Italy_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Italy2001 age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Italy2011_mean age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Italy_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Italy")
graph export "$project/results/figure_specialization_italy.pdf", as(pdf)  replace

* Portugal: ok * 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1981" 3 "1991" 4 "2001" 5 "2011" 6 "Mean") cols(1) rows(5) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Portugal_ave=rowmean(`var'Portugal*mean)
egen `var'Portugal_max=rowmax(`var'Portugal*mean)
quietly: sum `var'Portugal_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Portugal1981_mean age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Portugal1991_mean age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Portugal2001_mean age, mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Portugal2011_mean age, mcolor(purple%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'Portugal_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Portugal")
graph export "$project/results/figure_specialization_portugal.pdf", as(pdf)  replace
	
* Spain:  ok * 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1981" 3 "1991" 4 "2001" 5 "2011" 6 "Mean") cols(1) rows(5) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Spain_ave=rowmean(`var'Spain*mean)
egen `var'Spain_max=rowmax(`var'Spain*mean)
quietly: sum `var'Spain_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Spain1981_mean age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Spain1991_mean age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Spain2001_mean age, mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Spain2011_mean age, mcolor(purple%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'Spain_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Spain")
graph export "$project/results/figure_specialization_spain.pdf", as(pdf)  replace

* Switzerland: ok *
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1970" 3 "1980" 4 "1990" 5 "2000" 6  "Mean") cols(1) rows(5) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

egen `var'Switzerland_ave=rowmean(`var'Switzerland*mean)
egen `var'Switzerland_max=rowmax(`var'Switzerland*mean)
quietly: sum `var'Switzerland_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Switzerland1970_mean age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Switzerland1980_mean age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Switzerland1990_mean age, mcolor(gold%50) msymbol(circle)   mlcolor(black) lcolor(black)) ///
		(connected `var'Switzerland2000_mean age, mcolor(orange%50) msymbol(square)   mlcolor(black) lcolor(black)) ///
		(connected `var'Switzerland_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Switzerland")
graph export "$project/results/figure_specialization_switzerland.pdf", as(pdf)  replace

* UK: exception * 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "1991" 3 "2001" 4 "Mean") cols(1) rows(3) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

gen `var'UK_ave=(`var'UK1991_mean+`var'UK2001)/2
egen `var'UK_max=rowmax(`var'UK1991_mean `var'UK2001)
quietly: sum `var'UK_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'UK1991_mean age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'UK2001 age,      mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'UK_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, UK")
graph export "$project/results/figure_specialization_uk.pdf", as(pdf)  replace

* Netherlands: exception * 
foreach var in man_ope_job cman_ope_job rel_ope_job{

* title *
if "`var'"=="man_ope_job"{
local ttext "Share blue-collar manufacturing jobs"
local loptions legend(ring(0) pos(8) order(2 "2001" 3 "2011" 4 "Mean") cols(1) rows(3) region(lcolor(white)))
}
else if "`var'"=="cman_ope_job"{
local ttext "Share blue-collar jobs within manufacturing"
local loptions legend(off)
}
else if "`var'"=="rel_ope_job"{
local ttext `""Ratio of workers in blue-collar" "to white-collar and service jobs""'
local loptions legend(off)
}

gen `var'Netherlands_ave=(`var'Netherlands2001+`var'Netherlands2011)/2
egen `var'Netherlands_max=rowmax(`var'Netherlands2001 `var'Netherlands2011)
quietly: sum `var'Netherlands_max
replace upper_limit=`r(max)'
twoway 	(area upper_limit age if age>=50 & age<=65, fcolor(gs14) lcolor(gs14)) ///
		(connected `var'Netherlands2001 age, mcolor(blue%80) msymbol(square)   mlcolor(black) lcolor(black) mfcolor(blue%30) ) ///
		(connected `var'Netherlands2011 age, mcolor(red%50)  msymbol(triangle) mlcolor(black) lcolor(black)) ///
		(connected `var'Netherlands_ave  age, mcolor(black%80) msymbol(diamond) mfcolor(green%30) mlcolor(black) lcolor(black)), ///
		ytitle(`ttext' , size(large)) xtitle(Age) xlabel(20(5)80) ///
		`loptions'  graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) name(`var', replace)
		
}		
gr combine man_ope_job cman_ope_job rel_ope_job, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) ysize(3) xsize(8) cols(3) title("Comparative advantage patterns by age, Netherlands")
graph export "$project/results/figure_specialization_netherlands.pdf", as(pdf)  replace


