/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 1: 	Summary statistics for countries
			
Notes: 		1. Do-file does not currently generate any output. 
			This table is cardcoded in the Latex file.

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	...

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

**************************************
**********PANEL A*********************
***Aging and demographics          ***
**************************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*demographics variables*
gen change_dependency2025=(${aging_measure}2025-${aging_measure}1990)
gen change_dependency2015=(${aging_measure}2015-${aging_measure}1990)

* fast vs slow aging definition *
sum change_dependency2025, d
gen fast_aging=(change_dependency2025>r(p50))
gen slow_aging=(change_dependency2025<=r(p50))

*statistics for all countries*
sum ${aging_measure}1990 change_dependency2015 change_dependency2025 

*statistics for OECD countries*
sum ${aging_measure}1990 change_dependency2015 change_dependency2025 if new_region=="OECD"

*statistics for fast-aging countries*
sum ${aging_measure}1990 change_dependency2015 change_dependency2025 if fast_aging

*statistics for slow-aging countries*
sum ${aging_measure}1990 change_dependency2015 change_dependency2025 if slow_aging
	
**************************************
**********PANEL B*********************
***International Fed of Robotics   ***
**************************************
	
* covariates *
use "$project/clean_data/country_covariates.dta", clear
		
* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/$normalization_robots
gen robots2014=stock_robots_2014/$normalization_robots
gen robots1993=stock_robots_1993/$normalization_robots

* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  i.dreg
gen full_sample=e(sample)

* fast vs slow aging definition **demographics variables*
gen change_dependency2025=(${aging_measure}2025-${aging_measure}1990)
gen change_dependency2015=(${aging_measure}2015-${aging_measure}1990)
sum change_dependency2025 if full_sample, d
gen fast_aging=(change_dependency2025>r(p50)) if full_sample
gen slow_aging=(change_dependency2025<=r(p50)) if full_sample

*statistics for all countries*
sum robots2014 robots1993 change_robots   if full_sample

*statistics for OECD countries*
sum robots2014 robots1993 change_robots  if full_sample & new_region=="OECD"

*statistics for fast-aging countries*
sum robots2014 robots1993 change_robots  if full_sample & fast_aging

*statistics for slow-aging countries*
sum robots2014 robots1993 change_robots  if full_sample & slow_aging

**************************************
**********PANEL C, Part 1*************
***Statistics from Comtrade imports***
**************************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1996_2015.dta", assert(1 3) nogenerate
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* compute total imports of intermediate goods *
foreach flow in im_ ex_ re_{
egen intermediate_`flow'96=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}

*sample selection: drop japan---a large producer of robots*
drop if country_name=="japan" | country_name=="luxembourg"

* aging measure *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*outcome: share divided by total intermediate imports going back to 1996, the year that robot imports became available*
gen net_imports_robots=tv_im_robots_orig-tv_re_robots_orig
drop if net_imports_robots<=0
gen  real_imports_robots=net_imports_robots/$normalization_robots 
gen  share_imports_robots=1000000*net_imports_robots/intermediate_im_96 

*define sample*
quietly: reg share_imports_robots  change_dependency  $country_covariates  $imports_weights, r
gen full_sample=e(sample)
sum change_dependency if full_sample, d
gen fast_aging=(change_dependency>r(p50)) if full_sample
gen slow_aging=(change_dependency<=r(p50)) if full_sample

sum real_imports_robots if full_sample

sum real_imports_robots if full_sample & new_region=="OECD"

sum real_imports_robots if full_sample & fast_aging

sum real_imports_robots if full_sample & slow_aging

sum share_imports_robots $imports_weights if full_sample

sum share_imports_robots $imports_weights if full_sample & new_region=="OECD"

sum share_imports_robots $imports_weights if full_sample & fast_aging

sum share_imports_robots $imports_weights if full_sample & slow_aging

**************************************
**********PANEL C, Part 2*************
***Statistics from Comtrade exports***
**************************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* comtrade imports of intermediates *
merge 1:1 isocode using "${project}/clean_data/comtrade_1996_2015.dta", assert(1 3) nogenerate
merge 1:1 isocode using "${project}/clean_data/comtrade_robots_1996_2015.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

* compute total imports of intermediate goods *
foreach flow in im_ ex_ re_{
egen intermediate_`flow'96=rowtotal(tv_`flow'agriculture_machine tv_`flow'automatic_welding tv_`flow'capital_goods tv_`flow'computers tv_`flow'control_instruments tv_`flow'dedicated_food tv_`flow'dedicated_textile tv_`flow'industrial_robot tv_`flow'laundry_machine tv_`flow'machine_tools tv_`flow'manual_machtool tv_`flow'manual_tools tv_`flow'manual_welding tv_`flow'none tv_`flow'not_numerically_controlled tv_`flow'numerically_controlled tv_`flow'transfer_equipment tv_`flow'transfer_tools tv_`flow'vending_machine tv_`flow'weaving_textile), missing
}

*sample selection: drop Nigeria---a large outlier*
drop if country_name=="nigeria"

* aging measure *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*outcome: share divided by total intermediate exports going back to 1996, the year that robot exports became available*
drop if tv_ex_robots_orig<=0
gen  real_exports_robots=tv_ex_robots_orig/$normalization_robots
gen  share_exports_robots=1000000*tv_ex_robots_orig/intermediate_ex_96 

*define sample*
quietly: reg share_exports_robots  change_dependency  $country_covariates $exports_weights , r
gen full_sample=e(sample)
sum change_dependency if full_sample, d
gen fast_aging=(change_dependency>r(p50)) if full_sample
gen slow_aging=(change_dependency<=r(p50)) if full_sample

sum real_exports_robots if full_sample

sum real_exports_robots if full_sample & new_region=="OECD"

sum real_exports_robots if full_sample & fast_aging

sum real_exports_robots if full_sample & slow_aging

sum share_exports_robots $exports_weights if full_sample

sum share_exports_robots $exports_weights if full_sample & new_region=="OECD"

sum share_exports_robots $exports_weights if full_sample & fast_aging

sum share_exports_robots $exports_weights if full_sample & slow_aging


***********************************
**********PANEL D******************
***Statistics from Patent sample***
***********************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* patent data---drop others category *
merge 1:1 isocode using "${project}/clean_data/country_patents.dta", keep(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*aging variables
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
gen share_robots=1000*automation_rel if automation_rel>0
gen t_automation_rel=t_utility_patents*automation_rel

*define sample*
quietly: reg share_robots change_dependency   $country_covariates  , r
gen full_sample=e(sample)
sum change_dependency if full_sample, d
gen fast_aging=(change_dependency>r(p50)) if full_sample
gen slow_aging=(change_dependency<=r(p50)) if full_sample

sum t_automation_rel if full_sample

sum t_automation_rel if full_sample & new_region=="OECD" 

sum t_automation_rel if full_sample & fast_aging 

sum t_automation_rel if full_sample & slow_aging 

sum share_robots  [w=unido_MvaCod_1990] if full_sample

sum share_robots  [w=unido_MvaCod_1990] if full_sample & new_region=="OECD"

sum share_robots  [w=unido_MvaCod_1990] if full_sample & fast_aging==1

sum share_robots  [w=unido_MvaCod_1990] if full_sample & slow_aging==1




