/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A20: 	Relationship between aging and relative wages
			across commuting zones
			
Notes: 		1. uses data available in the replication kit of
            "Robots and Jobs: Evidence from US labor markets"
	        czones_exposure_longdif
			2. the single IV within the US is the decline in birthrates 
			between 1950 and 1980. This matches the period of 
			fast birthrate decline for the country as a whole
			3. data on relative wages from 1990 Census and 2006--2008 ACS

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_wages_czones_manuf.tex
			/results/table_wages_czones_manuf_um.tex
			/results/table_wages_czones_bmanuf.tex
			/results/table_wages_czones_bmanuf_um.tex
			/results/table_wages_czones_young.tex
			/results/table_wages_czones_young_um.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
* data from R&J *
use "${project}/clean_data/czones_exposure_longdif.dta", clear

* additional controls and measures of aging *
merge 1:1 czone using "${project}/clean_data/czones_demographics", assert(3) nogenerate

* data on relative wages *
merge 1:1 czone using "${project}/clean_data/czones_relative_wages_1990.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_relative_wages_2008.dta", assert(3) nogenerate

* define alternative instrument *
gen    single_iv=ln(brate1950)-ln(brate1980)
global instruments_czone brate*

* control variables *
gen nhgis_ln_gdp_1990=ln(nhgis_percapita_income_1990)
gen log_pop_1990=ln(population_1990)

*measures of aging: change in dependency ratio between 1990 and 2010 (wages measured between 1990--2008) *
gen change_dep=${aging_measure}2015-${aging_measure}1990
gen base_dep=${aging_measure}1990

* groups of covariates and measure of exposure (same as in table of integrators) *
global demographics_cz        base_dep nhgis_male_share_1990 nhgis_urban_share_1990  nhgis_ln_gdp_1990 log_pop_1990 nhgis_edu_*1990 nhgis_race_*1990 
global other_shocks_cz        chinashock_iv_90_07 expo_share_occ_routine_1990 expof_euro5_qo93_07 
global industry_shares_cz 	  nhgis_empsh_* 
global regional_dummies_cz    i.region

	************************
	*******Estimation*******
	************************ 
	
foreach var in manuf bmanuf young {

*Panel X: relative wage in manufacturing/blue-collar jobs/etc... *
cap drop change_wages
gen change_wages=ln(ipums_hrwage_`var'_2008/ipums_hrwage_2008)-ln(ipums_hrwage_`var'_1990/ipums_hrwage_1990)

reg     change_wages change_dep $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e1

reg     change_wages change_dep $industry_shares_cz $demographics_cz $regional_dummies_cz $exposure $other_shocks_cz, r cluster(state)
estimates store e2

ivreg2  change_wages (change_dep=$instruments_czone) $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e3

ivreg2  change_wages (change_dep=$instruments_czone) $industry_shares_cz $demographics_cz $regional_dummies_cz  $exposure $other_shocks_cz, r cluster(state)
estimates store e4

ivreg2  change_wages (change_dep=single_iv) $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e5

ivreg2  change_wages (change_dep=single_iv) $industry_shares_cz $demographics_cz $regional_dummies_cz  $exposure $other_shocks_cz, r cluster(state)
estimates store e6

estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_wages_czones_`var'.tex", style(tex) ///
varlabels(change_dep     "Aging 1990 and 2015" ) ///
		  cells(b(nostar  fmt(%9.3f)) se(par)) stats(N widstat jp, fmt(%7.0f %7.1f %7.2f) ///
		  labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" )) ///
		  nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

*Panel X: relative wage in manufacturing/blue-collar jobs/etc... *
cap drop change_wages
gen change_wages=ln(ipums_hrwage_`var'_um_2008/ipums_hrwage_um_2008)-ln(ipums_hrwage_`var'_um_1990/ipums_hrwage_um_1990)

reg     change_wages change_dep $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e1

reg     change_wages change_dep $industry_shares_cz $demographics_cz $regional_dummies_cz $exposure $other_shocks_cz, r cluster(state)
estimates store e2

ivreg2  change_wages (change_dep=$instruments_czone) $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e3

ivreg2  change_wages (change_dep=$instruments_czone) $industry_shares_cz $demographics_cz $regional_dummies_cz  $exposure $other_shocks_cz, r cluster(state)
estimates store e4

ivreg2  change_wages (change_dep=single_iv) $industry_shares_cz $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e5

ivreg2  change_wages (change_dep=single_iv) $industry_shares_cz $demographics_cz $regional_dummies_cz  $exposure $other_shocks_cz, r cluster(state)
estimates store e6


estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_wages_czones_`var'_um.tex", style(tex) ///
varlabels(change_dep     "Aging 1990 and 2015" ) ///
		  cells(b(nostar  fmt(%9.3f)) se(par)) stats(N widstat jp, fmt(%7.0f %7.1f %7.2f) ///
		  labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" )) ///
		  nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

}
