/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A5: 	Relationship between aging, other demogrpahic shifts,
			and institutional differences across countries

Notes: 		

Revision:   Pascual Restrepo
			Eric Donald 7/31/2020
			
Output: 	/results/table_correlation_hc.tex
			/results/table_correlation_flfp.tex
			/results/table_correlation_unions.tex
			/results/table_correlation_epl.tex
			/results/table_correlation_tax.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* human capital and schooling *
gen change_hc  =(bl_all_full_college2010-bl_all_full_college1990)/100 /* change in human capital from BL dataset, 1990--2010 (note: no data after 2010) */
gen change_flfp=(flfp_prime2015-flfp_prime1990)/100                   /* change in relative female labor force participation, 1990--2015 */

* union density *
gen union_density=rama_unions_85
replace union_density=ictwss_unions_90s if union_density==.
replace union_density=union_density/100

*Employment protection (normalized to 0--1)*
sum oecd_epl_v2
gen emp_protection=(oecd_epl_v2-r(min))/(r(max)-r(min))
*Tax wedge*
gen tax_wedge=oecd_taxwedge_00_SINGLE1/100


* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************ 
	
*****************************************************************************************
************************Table A5, Panel A: OLS models, college attainment ***************
*****************************************************************************************

reg change_hc 	change_dependency i.dreg if full_sample, r
estimates store e1

reg change_hc 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_hc	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_hc 	change_dependency if new_region=="OECD" & full_sample==1, r
estimates store e4

reg change_hc 	change_dependency $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e5

reg change_hc 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e6

* export table *
estout e1 e2 e3 e4 e5 e6  using  "$project/results/table_correlation_hc.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency ) 

*****************************************************************************************
**************Table A5, Panel B: OLS models, female labor force participation ***********
*****************************************************************************************


reg change_flfp 	change_dependency i.dreg if full_sample, r
estimates store e1

reg change_flfp 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg change_flfp	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg change_flfp 	change_dependency if new_region=="OECD" & full_sample==1, r
estimates store e4

reg change_flfp 	change_dependency $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e5

reg change_flfp 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e6

* export table *
estout e1 e2 e3 e4 e5 e6  using  "$project/results/table_correlation_flfp.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency ) 

*****************************************************************************************
**************Table A5, Panel C: OLS models, unionization *******************************
*****************************************************************************************

reg union_density 	change_dependency i.dreg if full_sample, r
estimates store e1

reg union_density 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg union_density	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg union_density 	change_dependency if new_region=="OECD" & full_sample==1, r
estimates store e4

reg union_density 	change_dependency $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e5

reg union_density 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e6

* export table *
estout e1 e2 e3 e4 e5 e6  using  "$project/results/table_correlation_unions.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency ) 

*****************************************************************************************
**************Table A5, Panel D: OLS models, employment protections *********************
*****************************************************************************************


reg emp_protection 	change_dependency i.dreg if full_sample, r
estimates store e1

reg emp_protection 	change_dependency i.dreg $country_covariates if full_sample, r
estimates store e2

reg emp_protection	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
estimates store e3

reg emp_protection 	change_dependency if new_region=="OECD" & full_sample==1, r
estimates store e4

reg emp_protection 	change_dependency $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e5

reg emp_protection 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e6

* export table *
estout e1 e2 e3 e4 e5 e6  using  "$project/results/table_correlation_epl.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency ) 

*****************************************************************************************
**************Table A5, Panel E: OLS models, labor tax *******************************
*****************************************************************************************

reg tax_wedge 	change_dependency if new_region=="OECD" & full_sample==1, r
estimates store e4

reg tax_wedge 	change_dependency $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e5

reg tax_wedge 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates  if new_region=="OECD" & full_sample==1, r
estimates store e6

* export table *
estout  e4 e5 e6  using  "$project/results/table_correlation_tax.tex", style(tex) extracols(1 1 1) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency ) ///
order(change_dependency ) 



