/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A7: 	First-stage estimates of past fertility
			rates on expected aging

Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_first_stage.tex			
			/results/table_first_stage_weighted.tex
			/results/table_first_stage_single.tex
			/results/table_first_stage_single_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************
	
	* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* human capital and schooling *
gen change_hc  =(bl_all_full_college2010-bl_all_full_college1990)/100
gen change_flfp=(flfp_prime2015-flfp_prime1990)/100

*rescale birthrates to shares
foreach year in 1950_1955 1955_1960 1960_1965 1970_1975 1975_1980 1980_1985{
replace birthrate`year'=(birthrate`year'/100)
}

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*****************************************************************************************	
*****************Table A7, Panel A: IV models first stage, unweighted *******************
*****************************************************************************************

reg change_dependency $instruments i.dreg if full_sample, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e1

reg change_dependency $instruments i.dreg $country_covariates if full_sample, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e2

reg change_dependency $instruments ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
test $instruments
estadd scalar Fstat=r(F)
estimates store e3

reg change_dependency $instruments change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e4

reg change_dependency $instruments if new_region=="OECD" & full_sample==1, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e5

reg change_dependency $instruments $country_covariates if new_region=="OECD" & full_sample==1, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e6

reg change_dependency $instruments ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e7

reg change_dependency $instruments change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e8


*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_first_stage.tex", style(tex) ///
varlabels(	birthrate1950_1955  "Birthrate 1950--1955" /// 
			birthrate1955_1960  "Birthrate 1955--1960" ///
			birthrate1960_1965  "Birthrate 1960--1965" ///
			birthrate1965_1970  "Birthrate 1965--1970" ///
			birthrate1970_1975  "Birthrate 1970--1975" ///
			birthrate1975_1980  "Birthrate 1975--1980" ///  
			birthrate1980_1985  "Birthrate 1980--1985"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(Fstat N r2, fmt(%7.1f %7.0f %7.2f) labels("First-stage $ F$  stat." "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep($instruments) ///
order($instruments)

*****************************************************************************************	
*****************Table A7, Panel C: IV models first stage, weighted *********************
*****************************************************************************************

reg change_dependency $instruments i.dreg if full_sample $robot_weight, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e1

reg change_dependency $instruments i.dreg $country_covariates if full_sample $robot_weight, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e2

reg change_dependency $instruments ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r
test $instruments
estadd scalar Fstat=r(F)
estimates store e3

reg change_dependency $instruments change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e4

reg change_dependency $instruments if new_region=="OECD" & full_sample==1 $robot_weight, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e5

reg change_dependency $instruments $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r 
test $instruments
estadd scalar Fstat=r(F)
estimates store e6

reg change_dependency $instruments ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e7

reg change_dependency $instruments change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r  
test $instruments
estadd scalar Fstat=r(F)
estimates store e8


*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_first_stage_weighted.tex", style(tex) ///
varlabels(	birthrate1950_1955  "Birthrate 1950--1955" /// 
			birthrate1955_1960  "Birthrate 1955--1960" ///
			birthrate1960_1965  "Birthrate 1960--1965" ///
			birthrate1965_1970  "Birthrate 1965--1970" ///
			birthrate1970_1975  "Birthrate 1970--1975" ///
			birthrate1975_1980  "Birthrate 1975--1980" ///  
			birthrate1980_1985  "Birthrate 1980--1985"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(Fstat N r2, fmt(%7.1f %7.0f %7.2f) labels("First-stage $ F$  stat." "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep($instruments) ///
order($instruments)

*****************************************************************************************	
**************Table A7, Panel B: single IV models first stage, unweighted ***************
*****************************************************************************************

reg change_dependency change_birthrate_60_80 i.dreg if full_sample, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e1

reg change_dependency change_birthrate_60_80 i.dreg $country_covariates if full_sample, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e2

reg change_dependency change_birthrate_60_80 ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e3

reg change_dependency change_birthrate_60_80 change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e4

reg change_dependency change_birthrate_60_80 if new_region=="OECD" & full_sample==1, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e5

reg change_dependency change_birthrate_60_80 $country_covariates if new_region=="OECD" & full_sample==1, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e6

reg change_dependency change_birthrate_60_80 ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e7

reg change_dependency change_birthrate_60_80 change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e8


*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_first_stage_single.tex", style(tex) ///
varlabels(	change_birthrate_60_80 "\multirow{2}{4cm}{Percent decline in fertility 1960--1985}"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(Fstat N r2, fmt(%7.1f %7.0f %7.2f) labels("First-stage $ F$  stat." "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_birthrate_60_80) ///
order(change_birthrate_60_80)

*****************************************************************************************	
**************Table A7, Panel D: single IV models first stage, weighted *****************
*****************************************************************************************

reg change_dependency change_birthrate_60_80 i.dreg if full_sample $robot_weight, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e1

reg change_dependency change_birthrate_60_80 i.dreg $country_covariates if full_sample $robot_weight, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e2

reg change_dependency change_birthrate_60_80 ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e3

reg change_dependency change_birthrate_60_80 change_hc change_flfp ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e4

reg change_dependency change_birthrate_60_80 if new_region=="OECD" & full_sample==1 $robot_weight, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e5

reg change_dependency change_birthrate_60_80 $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r 
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e6

reg change_dependency change_birthrate_60_80 ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e7

reg change_dependency change_birthrate_60_80 change_hc change_flfp ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" & full_sample==1 $robot_weight, r  
test change_birthrate_60_80
estadd scalar Fstat=r(F)
estimates store e8


*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 using  "$project/results/table_first_stage_single_weighted.tex", style(tex) ///
varlabels(	change_birthrate_60_80 "\multirow{2}{4cm}{Percent decline in fertility 1960--1985}"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(Fstat N r2, fmt(%7.1f %7.0f %7.2f) labels("First-stage $ F$  stat." "Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_birthrate_60_80) ///
order(change_birthrate_60_80)

