/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A8: 	IV estimates of the impact of aging on the adoption
			of industrial robots, with age-adjusted
			birthrates as instruments
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_adjusted_iv.tex
			/results/table_adjusted_iv_weighted.tex
			/results/table_adjusted_single_iv.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* sample selection: countries with robot data and full covariates, excluding Japan and Russia *
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

	************************
	*******Estimation*******
	************************   

*******************************************************************************************************
************************Table A8, Panel A: IV estimates using age-adjusted 5-year birthrates **********
*******************************************************************************************************
ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) i.dreg if full_sample, r partial(i.dreg) ffirst
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) i.dreg $country_covariates if full_sample, r partial(i.dreg) ffirst
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg) ffirst
estimates store e3


ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) if new_region=="OECD", r  ffirst
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) $country_covariates if new_region=="OECD", r  ffirst
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r  ffirst
estimates store e6


* export tables *
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_adjusted_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

*********************************************************************************************************************
************************Table A8, Panel C: IV models weighted by value added in manufacturing ***********************
*********************************************************************************************************************
ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) i.dreg if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e1

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) i.dreg $country_covariates if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e2

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample $robot_weight, r partial(i.dreg) ffirst
estimates store e3

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) if new_region=="OECD" $robot_weight, r ffirst 
estimates store e4

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) $country_covariates if new_region=="OECD" $robot_weight, r  ffirst
estimates store e5

ivreg2 change_robots 	(change_dependency=$instruments_adjusted ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" $robot_weight, r  ffirst
estimates store e6


* export tables *
estout e1 e2 e3 e4 e5 e6 using  "$project/results/table_adjusted_iv_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat jp arfp, fmt(%7.0f %7.1f %7.2f %7.2f) labels("Observations" "First-stage $ F$  stat." "Overid $ p-$ value" "Anderson-Rubin Wald test $ p-$ value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)

***********************************************************************************************************************************
************************Table A8, Panel B: IV estimates exploiting decline in birthrates between 1960--1980 ***********************
***********************************************************************************************************************************
ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) i.dreg if full_sample, r partial(i.dreg)
estimates store e1

ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e2

ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample, r partial(i.dreg)
estimates store e3

ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) if new_region=="OECD", r 
estimates store e4

ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) $country_covariates if new_region=="OECD", r 
estimates store e5

ivreg2 change_robots 	(change_dependency=change_birthrate_adj_60_80 ) ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD", r 
estimates store e6


* export tables *
estout e1 e2 e3 e4 e5 e6  using  "$project/results/table_adjusted_single_iv.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025"   ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat."  )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency) ///
order(change_dependency)



