/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A9: 	OLS estimates of the impact of population change
			in different age groups on the adoption of 
			industrial robots
			
Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_population_panelA.tex
			/results/table_population_panelA_weighted.tex
			/results/table_population_panelB.tex
			/results/table_population_panelB_weighted.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)

*aging variables*
gen change_logpop_00_100=log_pop_00_100_y2025-log_pop_00_100_y1990
gen change_logpop_00_35 =log_pop_00_35_y2025 -log_pop_00_35_y1990
gen change_logpop_00_55 =log_pop_00_55_y2025 -log_pop_00_55_y1990
gen change_logpop_20_35 =log_pop_20_35_y2025 -log_pop_20_35_y1990
gen change_logpop_20_55 =log_pop_20_55_y2025 -log_pop_20_55_y1990
gen change_logpop_35_55 =log_pop_35_55_y2025 -log_pop_35_55_y1990
gen change_logpop_55_75 =log_pop_55_75_y2025-log_pop_55_75_y1990
gen change_logpop_55_100=log_pop_55_100_y2025-log_pop_55_100_y1990
gen base_logpop_00_100=log_pop_00_100_y1990
gen base_logpop_00_35 =log_pop_00_35_y1990
gen base_logpop_00_55 =log_pop_00_55_y1990
gen base_logpop_20_35 =log_pop_20_35_y1990
gen base_logpop_20_55 =log_pop_20_55_y1990
gen base_logpop_35_55 =log_pop_35_55_y1990
gen base_logpop_55_75 =log_pop_55_75_y1990
gen base_logpop_55_100=log_pop_55_100_y1990

	************************
	*******Estimation*******
	************************   

*********************************************************************			
*Table A9, Panel A: models with size of population groups on the RHS*
***Groups from 20-55, from 55-100... Unweighted version  ************
*********************************************************************

*Change in stock for the full sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					if full_sample==1, r
estimates store e1
					
reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					if full_sample==1, r
estimates store e2

reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1, r
estimates store e3
					
*Change in stock for the OECD sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					if full_sample==1& new_region=="OECD", r
estimates store e4
					
reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					if full_sample==1& new_region=="OECD", r
estimates store e5

reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1& new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_population_panelA.tex", style(tex) ///
varlabels(change_logpop_20_55  "\multirow{2}{6.5cm}{Change in the log of population aged 20-55 years}" ///
		  change_logpop_55_100 "\multirow{2}{6.5cm}{Change in the log of population $\geq 56$ years}"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_logpop* ) ///
order(change_logpop_20_55 change_logpop_55_100 ) 

*********************************************************************				
*Table A9, Panel C: models with size of population groups on the RHS*
***Groups from 20-55, from 55-100... Weighted version  **************
*********************************************************************

*Change in stock for the full sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					if full_sample==1 $robot_weight , r
estimates store e1
					
reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					if full_sample==1  $robot_weight, r
estimates store e2

reg change_robots 	change_logpop_20_55 change_logpop_55_100 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1  $robot_weight, r
estimates store e3
					
*Change in stock for the OECD sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e4
					
reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e5

reg change_robots 	change_logpop_20_55 change_logpop_55_100  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_100  ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_population_panelA_weighted.tex", style(tex) ///
varlabels(change_logpop_20_55  "\multirow{2}{6.5cm}{Change in the log of population aged 20-55 years}" ///
		  change_logpop_55_100 "\multirow{2}{6.5cm}{Change in the log of population $\geq 56$ years}"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_logpop* ) ///
order(change_logpop_20_55 change_logpop_55_100 ) 

*********************************************************************					
*Table A9, Panel B: models with size of population groups on the RHS*
***Groups from 20-55, from 55-75  ***********************************
*********************************************************************

*Change in stock for the full sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					if full_sample==1, r
estimates store e1
					
reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					if full_sample==1, r
estimates store e2

reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1, r
estimates store e3
					
*Change in stock for the OECD sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_75  i.dreg ///
					if full_sample==1& new_region=="OECD", r
estimates store e4
					
reg change_robots 	change_logpop_20_55 change_logpop_55_75  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					if full_sample==1& new_region=="OECD", r
estimates store e5

reg change_robots 	change_logpop_20_55 change_logpop_55_75  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1& new_region=="OECD", r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_population_panelB.tex", style(tex) ///
varlabels(change_logpop_20_55 "\multirow{2}{6.5cm}{Change in the log of population aged 20-55 years}" ///
		  change_logpop_55_75 "\multirow{2}{6.5cm}{Change in the log of population aged 55-75 years}" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_logpop* ) ///
order(change_logpop_20_55 change_logpop_55_75 ) 

*********************************************************************					
*Table A9, Panel D: models with size of population groups on the RHS*
***Groups from 20-55, from 55-75  ***********************************
*********************************************************************

*Change in stock for the full sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					if full_sample==1  $robot_weight, r
estimates store e1
					
reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					if full_sample==1  $robot_weight, r
estimates store e2

reg change_robots 	change_logpop_20_55 change_logpop_55_75 i.dreg ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1  $robot_weight, r
estimates store e3
					
*Change in stock for the OECD sample:
reg change_robots 	change_logpop_20_55 change_logpop_55_75  i.dreg ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e4
					
reg change_robots 	change_logpop_20_55 change_logpop_55_75  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e5

reg change_robots 	change_logpop_20_55 change_logpop_55_75  ///
					$country_covariates_min base_logpop_20_55 base_logpop_55_75 ///
					ln_manuf_va base1993_stock_pc  ///
					if full_sample==1& new_region=="OECD"  $robot_weight, r
estimates store e6

*Export tables*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table_population_panelB_weighted.tex", style(tex) ///
varlabels(change_logpop_20_55 "\multirow{2}{6.5cm}{Change in the log of population aged 20-55 years}" ///
		  change_logpop_55_75 "\multirow{2}{6.5cm}{Change in the log of population aged 55-75 years}" ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_logpop* ) ///
order(change_logpop_20_55 change_logpop_55_75 ) 

					
